@@ -11,9 +11,11 @@ OC.L10N.register(
     "Mails" : "El. laiškai",
     "Mail" : "Paštas",
     "💌 A mail app for Nextcloud" : "💌 Pašto programėlė, skirta Nextcloud",
+    "Your session has expired. The page will be reloaded." : "Jūsų seansas nebegalioja. Puslapis bus įkeltas iš naujo.",
     "Drafts are saved in:" : "Juodraščiai yra įrašomi į:",
     "Sent messages are saved in:" : "Išsiųsti laiškai yra įrašomi į:",
     "Deleted messages are moved in:" : "Ištrinti laiškai yra perkeliami į:",
+    "Archived messages are moved in:" : "Archyvuoti laiškai yra perkeliami į:",
     "Auto" : "Automatiškai",
     "Name" : "Vardas",
     "Mail address" : "El. pašto adresas",
@@ -41,13 +43,14 @@ OC.L10N.register(
     "Checking mail host connectivity" : "Tikrinamas jungiamumas su pašto serveriu",
     "Configuration discovery failed. Please use the manual settings" : "Nepavyko atrasti konfigūracijos. Naudokite rankinius nustatymus",
     "Testing authentication" : "Išbandomas tapatybės nustatymas",
-    "Account created" : "Paskyra sukurta",
     "Account updated" : "Paskyra atnaujinta",
-    "Changes saved" : "Pakeitimai įrašyti",
     "IMAP server is not reachable" : "IMAP serveris yra nepasiekiamas",
     "SMTP server is not reachable" : "SMTP serveris yra nepasiekiamas",
     "IMAP username or password is wrong" : "Neteisingas IMAP naudotojo vardas ar slaptažodis",
     "SMTP username or password is wrong" : "Neteisingas SMTP naudotojo vardas ar slaptažodis",
+    "IMAP connection failed" : "IMAP ryšys patyrė nesėkmę",
+    "SMTP connection failed" : "SMTP ryšys patyrė nesėkmę",
+    "There was an error while setting up your account" : "Nustatant jūsų paskyrą įvyko klaida",
     "Account settings" : "Paskyros nustatymai",
     "Change name" : "Keisti vardą",
     "Signature" : "Parašas",
@@ -55,6 +58,8 @@ OC.L10N.register(
     "Writing mode" : "Rašymo veiksena",
     "Preferred writing mode for new messages and replies." : "Pageidaujama rašymo veiksena naujuose laiškuose ir atsakant į laiškus.",
     "Default folders" : "Numatytieji aplankai",
+    "The folders to use for drafts, sent messages, deleted messages and archived messages." : "Aplankai, kurie bus naudojami juodraščiams, išsiųstiems laiškams, ištrintiems laiškams ir archyvuotiems laiškams laikyti.",
+    "Autoresponder" : "Atsakiklis",
     "Trusted senders" : "Patikimi siuntėjai",
     "Mail server" : "Pašto serveris",
     "Email address" : "El. pašto adresas",
@@ -64,7 +69,9 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
     "Register as application for mail links" : "Registruoti kaip pašto nuorodų programėlę",
     "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
+    "Looking for a way to encrypt your emails?" : "Ieškote būdo šifruoti el. laiškus?",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Leisti programėlei rinkti duomenis apie jūsų sąveikas. Remiantis šiais duomenimis, programėlė prisitaikys prie jūsų nuostatų. Duomenys bus laikomi tik vietoje.",
+    "Could not update preference" : "Nepavyko atnaujinti nuostatos",
     "From" : "Nuo",
     "Select account" : "Pasirinkti paskyrą",
     "To" : "Kam",
@@ -86,6 +93,7 @@ OC.L10N.register(
     "Add attachment from Files" : "Pridėti priedą iš Failų",
     "Send later" : "Siųsti vėliau",
     "Enable formatting" : "Įjungti formatavimą",
+    "Disable formatting" : "Išjungti formatavimą",
     "Encrypt message with Mailvelope" : "Šifruoti laišką naudojant Mailvelope",
     "Send now" : "Siųsti dabar",
     "Enter a date" : "Įveskite datą",
@@ -99,6 +107,9 @@ OC.L10N.register(
     "Send" : "Siųsti",
     "Encrypt and send" : "Šifruoti ir siųsti",
     "Send unencrypted" : "Siųsti nešifruotą",
+    "Turn off formatting" : "Išjungti formatavimą",
+    "Turn off and remove formatting" : "Išjungti ir šalinti formatavimą",
+    "Keep formatting" : "Palikti formatavimą",
     "Choose a file to add as attachment" : "Pasirinkite failą, kurį prisegsite prie laiško",
     "Choose a file to share as a link" : "Pasirinkite failą, kurį bendrinsite kaip nuorodą",
     "_{count} attachment_::_{count} attachments_" : ["{count} priedas","{count} priedai","{count} priedų","{count} priedas"],
@@ -106,7 +117,11 @@ OC.L10N.register(
     "Set up an account" : "Nusistatyti paskyrą",
     "Plain text" : "Grynasis tekstas",
     "Rich text" : "Raiškusis tekstas",
+    "No messages in this mailbox" : "Šioje pašto dėžutėje laiškų nėra",
+    "No messages" : "Nėra laiškų",
     "Draft: " : "Juodraštis: ",
+    "Encrypted message" : "Šifruotas laiškas",
+    "This message is unread" : "Šis laiškas yra neskaitytas",
     "Unfavorite" : "Nebežymėti kaip mėgstamą",
     "Favorite" : "Mėgstamas",
     "Read" : "Skaityti",
@@ -120,6 +135,7 @@ OC.L10N.register(
     "Download message" : "Atsisiųsti laišką",
     "No subject" : "Be temos",
     "Could not delete message" : "Nepavyko ištrinti laiško",
+    "Could not archive message" : "Nepavyko archyvuoti laiško",
     "Forward" : "Persiųsti",
     "Load more" : "Įkelti daugiau",
     "_Mark {number} unread_::_Mark {number} unread_" : ["Žymėti {number} kaip neskaitytą","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytus","Žymėti {number} kaip neskaitytą"],
@@ -127,6 +143,7 @@ OC.L10N.register(
     "Report this bug" : "Pranešti apie šią klaidą",
     "All day" : "Visą dieną",
     "Create" : "Sukurti",
+    "Event created" : "Įvykis sukurtas",
     "Could not create event" : "Nepavyko sukurti įvykio",
     "Comment" : "Komentaras",
     "Accept" : "Priimti",
@@ -151,8 +168,10 @@ OC.L10N.register(
     "Unnamed" : "Be pavadinimo",
     "Embedded message" : "Įterptas laiškas",
     "Choose a folder to store the attachment in" : "Pasirinkite aplanką, kuriame išsaugoti priedą",
+    "View fewer attachments" : "Rodyti mažiau priedų",
     "Save all to Files" : "Įrašyti visus į Failus",
     "Choose a folder to store the attachments in" : "Pasirinkite aplanką, kuriame laikyti priedus",
+    "_View {count} more attachment_::_View {count} more attachments_" : ["Rodyti dar {count} priedą","Rodyti dar {count} priedus","Rodyti dar {count} priedų","Rodyti dar {count} priedą"],
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Šis laiškas yra šifruotas naudojant PGP. Norėdami jį iššifruoti, įsidiekite Mailvelope.",
     "The images have been blocked to protect your privacy." : "Tam, kad būtų apsaugotas jūsų privatumas, paveikslai buvo užblokuoti.",
     "Show images" : "Rodyti paveikslus",
@@ -220,10 +239,12 @@ OC.L10N.register(
     "Unset" : "Nenustatyta",
     "Add tag" : "Pridėti žymę",
     "Tag already exists" : "Žymė jau yra",
+    "An error occurred, unable to create the tag." : "Įvyko klaida, nepavyko sukurti žymės.",
+    "An error occurred, unable to rename the tag." : "Įvyko klaida, nepavyko pervadinti žymės.",
+    "Not found" : "Nerasta",
     "Mark as unread" : "Žymėti kaip neskaitytą",
     "Mark as read" : "Žymėti kaip skaitytą",
     "Delete message" : "Ištrinti laišką",
-    "Not found" : "Nerasta",
     "Remove" : "Šalinti",
     "No senders are trusted at the moment." : "Šiuo metu nėra patikimų siuntėjų.",
     "Could not remove trusted sender {sender}" : "Nepavyko pašalinti patikimo siuntėjo {sender}",
@@ -244,6 +265,8 @@ OC.L10N.register(
     "Error saving config" : "Klaida įrašant konfigūraciją",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Pradinis laiškas bus pridėtas kaip priedas „message/rfc822“.",
     "Reset" : "Atstatyti",
+    "Client ID" : "Kliento ID",
+    "Client secret" : "Kliento paslaptis",
     "Email: {email}" : "El. paštas: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} ties {host}:{port} ({ssl} šifravimas)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} ties {host}:{port} ({ssl} šifravimas)",
@@ -256,6 +279,7 @@ OC.L10N.register(
     "SMTP" : "SMTP",
     "Save Config" : "Įrašyti konfigūraciją",
     "With the settings above, the app will create account settings in the following way:" : "Naudodama aukščiau esančius nustatymus, programėlė sukurs paskyrai nustatymus štai tokiu būdu: ",
+    "Account connected" : "Paskyra prijungta",
     "Keyboard shortcut" : "Spartusis klavišas",
     "Keyboard shortcuts" : "Klaviatūros greitieji klavišai",
     "Speed up your Mail experience with these quick shortcuts." : "Padidinkite savo našumą naudodamiesi šiomis nuorodomis.",
